@@ -48,7 +48,6 @@ Item *create_item(const char *name, const char *value) {
         itm->value = g_string_new(value);
     return itm;
 }
-
 /*******************************************************************************/
 void destroy_item(Item ** item) {
 #ifdef DEBUGFUNCTIONCALL
@@ -70,7 +69,6 @@ void destroy_item(Item ** item) {
     END_FUNCTION;
 #endif
 }
-
 /*******************************************************************************/
 GSList *add_item2object(GSList ** object, void *item) {
 #ifdef DEBUGFUNCTIONCALL
@@ -80,7 +78,6 @@ GSList *add_item2object(GSList ** object, void *item) {
         *object = g_slist_append(*object, item);
     return (*object);
 }
-
 /*******************************************************************************/
 char *item_value(GSList * object, const char *name) {
     GString *tmp = NULL;
@@ -103,7 +100,6 @@ char *item_value(GSList * object, const char *name) {
     }
     return result;
 }
-
 /*******************************************************************************/
 time_t calculate_diff_time(int timezone) {
 
@@ -121,7 +117,6 @@ time_t calculate_diff_time(int timezone) {
 
     return diff_time;
 }
-
 /*******************************************************************************/
 void destroy_object(GSList ** object) {
     Item *itm = NULL;
@@ -165,7 +160,27 @@ time_t last_update_time(GSList * object) {
 #endif
     return last_update;
 }
+/*******************************************************************************/
+time_t last_update_time_new(GHashTable *object) {
+    time_t last_update = 0;
+    struct tm tm = { 0 };
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    if(!object || !g_hash_table_lookup(object, "last_update"))
+        return 0;
+    strptime(g_hash_table_lookup(object, "last_update"), "%D %I:%M", &tm);
+    tm.tm_isdst = 1;
+    last_update = mktime(&tm);
 
+    /* Add 12 hours if  date have PM field */
+    if(strstr(g_hash_table_lookup(object, "last_update"), "PM"))
+        last_update += 12 * 3600;
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    return last_update;
+}
 /*******************************************************************************/
 #ifndef RELEASE
 void display_all_object_items(GSList * object) {
