@@ -39,10 +39,12 @@
 #define EARTH_RADIUS (3443.91847)
 #define deg2rad(deg) ((deg) * (PI / 180.0))
 /*******************************************************************************/
-gdouble
-calculate_distance(gdouble lat1, gdouble lon1, gdouble lat2,
-                   gdouble lon2) {
+double
+calculate_distance(double lat1, double lon1, double lat2,
+                   double lon2) {
     gdouble dlat, dlon, slat, slon, a;
+    gchar buffer[100];
+
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
