@@ -337,6 +337,36 @@ list_changed(GtkTreeSelection *sel,  gpointer user_data, gchar *name){
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
+}/*******************************************************************************/
+void
+clear_station(GtkWidget *window){
+    GtkWidget       *dialog_window = NULL,
+                    *label = NULL;
+    gint result;
+
+    dialog_window = gtk_dialog_new_with_buttons(_("Warning"), NULL,
+            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, NULL);
+    label = gtk_label_new(_("Are you sure?"));
+    set_font(label, NULL, 20);
+    gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog_window)->vbox), label);
+    gtk_dialog_add_button (GTK_DIALOG (dialog_window), GTK_STOCK_NO, GTK_RESPONSE_NO);
+    gtk_dialog_add_button (GTK_DIALOG (dialog_window), GTK_STOCK_YES, GTK_RESPONSE_YES);
+
+    gtk_widget_show_all(dialog_window);
+
+    result = gtk_dialog_run(GTK_DIALOG(dialog_window));
+    if (result == GTK_RESPONSE_YES){
+        g_object_set_data(G_OBJECT(window), "station_name", " ");
+        g_object_set_data(G_OBJECT(window), "station_code", " ");
+        g_object_set_data(G_OBJECT(window), "station_source", " ");
+        gtk_toggle_button_set_active(g_object_get_data(G_OBJECT(window), "manual_button"), TRUE);
+        gtk_toggle_button_set_active(g_object_get_data(G_OBJECT(window), "gps_button"), FALSE);
+        save_station(window);
+    }
+
+    if (dialog_window)
+        gtk_widget_destroy(dialog_window);
+
 }
 /*******************************************************************************/
 void
@@ -352,7 +382,7 @@ save_station(GtkWidget *window){
     START_FUNCTION;
 #endif
 
-    if (gtk_toggle_button_get_active(g_object_get_data(G_OBJECT(window), "gps")))
+    if (gtk_toggle_button_get_active(g_object_get_data(G_OBJECT(window), "gps_button")))
         is_gps = TRUE;
     else
         is_gps = FALSE;
@@ -482,7 +512,7 @@ choose_button_handler(GtkWidget *button, GdkEventButton *event,
     }
 
     gtk_container_add((GtkContainer *)scrolled_window, (GtkWidget *)list_view);
-    
+
     gtk_table_attach_defaults(GTK_TABLE(main_table),
                               scrolled_window, 1, 2, 1, 2);
 
@@ -1279,7 +1309,7 @@ station_setup_button_handler(GtkWidget *button, GdkEventButton *event,
     gtk_radio_button_set_group(GTK_RADIO_BUTTON(gps_button), group);
     gtk_box_pack_start (GTK_BOX (hbox), gps_button, TRUE, TRUE, 0);
     gtk_widget_show (hbox);
-    g_object_set_data(G_OBJECT(window), "gps", (gpointer)gps_button);
+    g_object_set_data(G_OBJECT(window), "gps_button", (gpointer)gps_button);
     if (g_object_get_data(G_OBJECT(button), "station_is_gps"))
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gps_button),
                                      TRUE);
@@ -1352,7 +1382,10 @@ station_setup_button_handler(GtkWidget *button, GdkEventButton *event,
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
                        main_table, TRUE, TRUE, 0);
 
+    gtk_dialog_add_button (GTK_DIALOG (window), GTK_STOCK_CLEAR, GTK_RESPONSE_NO);
     gtk_dialog_add_button (GTK_DIALOG (window), GTK_STOCK_SAVE, GTK_RESPONSE_YES);
+
+
     gtk_widget_show_all(window);
 
 
@@ -1361,6 +1394,8 @@ station_setup_button_handler(GtkWidget *button, GdkEventButton *event,
 
     if (result == GTK_RESPONSE_YES)
         save_station(window);
+    if (result == GTK_RESPONSE_NO)
+        clear_station(window);
     if (window)
         gtk_widget_destroy(window);
 
@@ -1918,10 +1953,12 @@ weather_simple_window_settings(gpointer user_data){
 
 /* start dialog window */
     result = gtk_dialog_run(GTK_DIALOG(window));
-    if (result == GTK_RESPONSE_YES)
+    if (result == GTK_RESPONSE_YES){
         /* Save config file */
         config_save(app->config);
-
+        /* Update information about connection to Internet */
+        check_current_connection();
+    }
     if (window)
         gtk_widget_destroy(window);
 #ifdef DEBUGFUNCTIONCALL
