@@ -125,7 +125,7 @@ weather_simple_window_status(GtkWidget *widget, gpointer user_data){
     gtk_widget_show (vertical1_alignmnet);
 
 
-    hbox_view_mode = gtk_hbox_new(TRUE, 0);
+/*    hbox_view_mode = gtk_hbox_new(TRUE, 0);
     group_view_mode = NULL;
     collapsed_button  = gtk_radio_button_new(NULL);
     gtk_container_add(GTK_CONTAINER(collapsed_button), gtk_label_new(_("Collapsed")));
@@ -149,7 +149,7 @@ weather_simple_window_status(GtkWidget *widget, gpointer user_data){
     gtk_table_attach((GtkTable*)main_table, hbox_view_mode,
                                 1, 3, 3, 4,
                                 GTK_FILL | GTK_EXPAND,
-                                (GtkAttachOptions)0, 5, 0 );
+                                (GtkAttachOptions)0, 5, 0 );*/
 
     fprintf(stderr, "\n%d\n", app->config->view_mode);
 
@@ -178,7 +178,8 @@ weather_simple_window_status(GtkWidget *widget, gpointer user_data){
     gtk_widget_set_size_request(help_button, 320, 60);
     gtk_widget_show (help_button);
     gtk_table_attach((GtkTable*)main_table, help_button,
-                                1, 3, 5, 6, (GtkAttachOptions)0,
+//                                1, 3, 5, 6, (GtkAttachOptions)0,
+                                1, 3, 3, 4, (GtkAttachOptions)0,
                                 (GtkAttachOptions)0, 5, 0 );
     g_signal_connect_after(help_button, "clicked",
                         G_CALLBACK(about_button_handler), NULL);
