@@ -29,7 +29,7 @@
 #include "weather-sources.h"
 #include "weather-utils.h"
 #include <string.h>
-#define		SOURCES_LIB	"/usr/lib/omweather"
+#define SOURCES_LIB "/usr/lib/omweather"
 /*******************************************************************************/
 GtkListStore*
 create_sources_list(gchar *sources_path, gint *sources_number, GSList **handles){
@@ -59,6 +59,7 @@ create_sources_list(gchar *sources_path, gint *sources_number, GSList **handles)
         snprintf(buffer, sizeof(buffer) - 1, "%s%s", sources_path,
                                               (gchar*)(tmp->data));
         source = parse_source_file(buffer, "UTF-8");
+
         if(source){
             if(source_name_valid(source)
                && source_library_valid(source, handles)
@@ -75,6 +76,7 @@ create_sources_list(gchar *sources_path, gint *sources_number, GSList **handles)
         }
         g_free(tmp->data);
         tmp = g_slist_next(tmp);
+
     }
     g_slist_free(db_set);
 
@@ -83,6 +85,74 @@ create_sources_list(gchar *sources_path, gint *sources_number, GSList **handles)
     return list;
 }
 /*******************************************************************************/
+gpointer
+get_source_parser(GtkListStore *data, const gchar *source_name){
+    GtkTreeIter iter;
+    GHashTable  *source = NULL;
+    gpointer    value = NULL;
+    gboolean    valid = FALSE;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    if(!data && !source_name)
+        return NULL;
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(data), &iter);
+    while(valid){
+        gtk_tree_model_get(GTK_TREE_MODEL(data), &iter, 1, &source, -1);
+        value = g_hash_table_lookup(source, "name");
+        if(source_name && value && !strcmp(source_name, (gchar*)value))
+            return g_hash_table_lookup(source, "parser");
+        valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(data), &iter);
+    }
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    return NULL;
+}
+/*******************************************************************************/
+gpointer
+get_source_hash(GtkListStore *data, const gchar *source_name){
+    GtkTreeIter iter;
+    GHashTable  *source = NULL;
+    gpointer    value = NULL;
+    gboolean    valid = FALSE;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    if(!data && !source_name)
+        return NULL;
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(data), &iter);
+    while(valid){
+        gtk_tree_model_get(GTK_TREE_MODEL(data), &iter, 1, &source, -1);
+        value = g_hash_table_lookup(source, "name");
+        if(value && !strcmp(source_name, (gchar*)value))
+            return source;
+        valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(data), &iter);
+    }
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    return NULL;
+}
+/*******************************************************************************/
+gpointer
+get_first_source_hash(GtkListStore *data){
+    GtkTreeIter iter;
+    GHashTable  *source = NULL;
+    gboolean    valid = FALSE;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    if(!data)
+        return NULL;
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(data), &iter);
+    gtk_tree_model_get(GTK_TREE_MODEL(data), &iter, 1, &source, -1);
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    return source;
+}
+/*******************************************************************************/
 void
 unload_parsers(GSList *list){
     GSList  *tmp = list;
@@ -99,125 +169,126 @@ source_name_valid(GHashTable *data){
     START_FUNCTION;
 #endif
     if(!data)
-	return FALSE;
+        return FALSE;
     /* check name */
     value = g_hash_table_lookup(data, "name");
     if(!value)
-	return FALSE;
+        return FALSE;
     else
-	return TRUE;
+        return TRUE;
 }
 /*******************************************************************************/
 gboolean
 source_library_valid(GHashTable *data, GSList **handles){
-    gpointer	value = NULL,
-		handle = NULL,
-		parser = NULL;
-    gchar	buffer[256];
+    gpointer        value = NULL,
+                    handle = NULL,
+                    parser = NULL;
+    gchar           buffer[256];
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
     if(!data)
-	return FALSE;
+        return FALSE;
     /* check libomweather-xxx-source.so file */
     value = g_hash_table_lookup(data, "library");
     if(!value)/* library file does not defined */
-	return FALSE;
+        return FALSE;
     else{
-	*buffer = 0;
-	snprintf(buffer, sizeof(buffer) - 1, "%s/%s",
-		    SOURCES_LIB, (gchar*)value);
-	if(access(buffer, R_OK))/* file does not exist or no permissions */
-	    return FALSE;
-	handle = dlopen(buffer, RTLD_NOW);
-	if(handle){
-	    dlerror();
-	    parser = dlsym(handle, "get_station_weather_data");
-	    if(!dlerror()){
-		g_hash_table_insert(data, "parser", parser);
-		/* store opening library handle */
-		*handles = g_slist_append(*handles, handle);
-	    }
-	}
+        *buffer = 0;
+        snprintf(buffer, sizeof(buffer) - 1, "%s/%s", SOURCES_LIB,
+                    (gchar*)value);
+        if(access(buffer, R_OK))/* file does not exist or no permissions */
+            return FALSE;
+        handle = dlopen(buffer, RTLD_NOW);
+        if(handle){
+            dlerror();
+            parser = dlsym(handle, "get_station_weather_data");
+            if(!dlerror()){
+                g_hash_table_insert(data, "parser", parser);
+                /* store opening library handle */
+                *handles = g_slist_append(*handles, handle);
+            }
+        }
     }
     return TRUE;
 }
 /*******************************************************************************/
 gboolean
 source_forecast_url_valid(GHashTable *data){
-    gpointer	value;
+    gpointer        value;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
     if(!data)
-	return FALSE;
+        return FALSE;
     /* check forecast url*/
     value = g_hash_table_lookup(data, "forecast_url");
     if(!(value && strstr(value, "%s")))
-	return FALSE;
+        return FALSE;
     else
-	return TRUE;
+        return TRUE;
 }
 /*******************************************************************************/
 gboolean
 source_detail_url_valid(GHashTable *data){
-    gpointer	value;
+    gpointer        value;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
     if(!data)
-	return FALSE;
+        return FALSE;
     /* check detail url*/
     value = g_hash_table_lookup(data, "detail_url");
     if(!(value && strstr(value, "%s")))
-	return FALSE;
+        return FALSE;
     else
-	return TRUE;
+        return TRUE;
 }
 /*******************************************************************************/
 gboolean
 source_search_url_valid(GHashTable *data){
-    gpointer	value;
+    gpointer        value;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
     if(!data)
-	return FALSE;
+        return FALSE;
     /* check search url*/
     value = g_hash_table_lookup(data, "search_url");
     if(!(value && strstr(value, "%s")))
-	return FALSE;
+        return FALSE;
     else
-	return TRUE;
+        return TRUE;
 }
 /*******************************************************************************/
 gboolean
 source_stations_database_valid(GHashTable *data){
-    gpointer	value;
-    gchar	buffer[256];
+    gpointer        value;
+    gchar           buffer[256];
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
     if(!data)
-	return FALSE;
+        return FALSE;
     /* check *.db file */
     value = g_hash_table_lookup(data, "base");
+    
     if(!value)/* database file does not defined */
-	return FALSE;
+        return FALSE;
     else{
-	*buffer = 0;
-	snprintf(buffer, sizeof(buffer) - 1, "%s%s",
-		    DATABASEPATH, (gchar*)value);
-	if(access(buffer, R_OK))/* file does not exist or no permissions */
-	    return FALSE;
+        *buffer = 0;
+        snprintf(buffer, sizeof(buffer) - 1, "%s%s", DATABASEPATH,
+                    (gchar*)value);
+        if(access(buffer, R_OK))/* file does not exist or no permissions */
+            return FALSE;
     }
     return TRUE;
 }
 /*******************************************************************************/
 gboolean
 source_logo_file_valid(GHashTable *data){
-    gpointer	value;
-    gchar	buffer[256];
+    gpointer        value;
+    gchar           buffer[256];
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -261,82 +332,148 @@ parse_source_file(const gchar *filename, const gchar *encoding){
     return object;
 }
 /*******************************************************************************/
-static void
-free_source_field (gpointer key, gpointer val, gpointer user_data)
-{
+void
+free_source_field(gpointer key, gpointer val, gpointer user_data){
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
     /* "parser" is not *gchar */
-    if (strcmp ("parser",key)){
+    if(strcmp ("parser",key)){
         g_free(val);
         val = NULL;
     }
 }
-
 /*******************************************************************************/
 void
 free_hashtable_with_source(GHashTable* hashtable){
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    g_hash_table_foreach (hashtable,
-        free_source_field, NULL);
-    g_hash_table_destroy (hashtable);
+    g_hash_table_foreach(hashtable, free_source_field, NULL);
+    g_hash_table_destroy(hashtable);
 }
 /*******************************************************************************/
 void
 parse_children(xmlNode *node, GHashTable *object){
-    xmlChar	*value = NULL;
+    xmlChar     *value = NULL;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
     while(node){
-	if(node->type == XML_ELEMENT_NODE){
-	    /* name */
-	    if(!xmlStrcmp(node->name, (const xmlChar*)"name")){
-		value = xmlNodeGetContent(node);
-		g_hash_table_insert(object, "name", g_strdup((gchar*)value));
-		xmlFree(value);
-	    }
-	    /* logo */
-	    if(!xmlStrcmp(node->name, (const xmlChar*)"logo")){
-		value = xmlNodeGetContent(node);
-		g_hash_table_insert(object, "logo", g_strdup((gchar*)value));
-		xmlFree(value);
-	    }
-	    /* forecast_url */
-	    if(!xmlStrcmp(node->name, (const xmlChar*)"forecast")){
-		value = xmlGetProp(node, (const xmlChar*)"url");
-		g_hash_table_insert(object, "forecast_url", g_strdup((gchar*)value));
-		xmlFree(value);
-	    }
-	    /* detail_url */
-	    if(!xmlStrcmp(node->name, (const xmlChar*)"detail")){
-		value = xmlGetProp(node, (const xmlChar*)"url");
-		g_hash_table_insert(object, "detail_url", g_strdup((gchar*)value));
-		xmlFree(value);
-	    }
-	    /* search_url */
-	    if(!xmlStrcmp(node->name, (const xmlChar*)"search")){
-		value = xmlGetProp(node, (const xmlChar*)"url");
-		g_hash_table_insert(object, "search_url", g_strdup((gchar*)value));
-		xmlFree(value);
-	    }
-	    /* stations_db */
-	    if(!xmlStrcmp(node->name, (const xmlChar*)"base")){
-		value = xmlNodeGetContent(node);
-		g_hash_table_insert(object, "base", g_strdup((gchar*)value));
-		xmlFree(value);
-	    }
-	    /* library */
-	    if(!xmlStrcmp(node->name, (const xmlChar*)"library")){
-		value = xmlNodeGetContent(node);
-		g_hash_table_insert(object, "library", g_strdup((gchar*)value));
-		xmlFree(value);
-	    }
-	}
-	node = node->next;
+        if(node->type == XML_ELEMENT_NODE){
+            /* name */
+            if(!xmlStrcmp(node->name, (const xmlChar*)"name")){
+                value = xmlNodeGetContent(node);
+                g_hash_table_insert(object, "name", g_strdup((gchar*)value));
+                xmlFree(value);
+            }
+            /* logo */
+            if(!xmlStrcmp(node->name, (const xmlChar*)"logo")){
+                value = xmlNodeGetContent(node);
+                g_hash_table_insert(object, "logo", g_strdup((gchar*)value));
+                xmlFree(value);
+            }
+            /* forecast_url */
+            if(!xmlStrcmp(node->name, (const xmlChar*)"forecast")){
+                value = xmlGetProp(node, (const xmlChar*)"url");
+                g_hash_table_insert(object, "forecast_url", g_strdup((gchar*)value));
+                xmlFree(value);
+            }
+            /* detail_url */
+            if(!xmlStrcmp(node->name, (const xmlChar*)"detail")){
+                value = xmlGetProp(node, (const xmlChar*)"url");
+                g_hash_table_insert(object, "detail_url", g_strdup((gchar*)value));
+                xmlFree(value);
+            }
+            /* search_url */
+            if(!xmlStrcmp(node->name, (const xmlChar*)"search")){
+                value = xmlGetProp(node, (const xmlChar*)"url");
+                g_hash_table_insert(object, "search_url", g_strdup((gchar*)value));
+                xmlFree(value);
+            }
+            /* stations_db */
+            if(!xmlStrcmp(node->name, (const xmlChar*)"base")){
+                value = xmlNodeGetContent(node);
+                g_hash_table_insert(object, "base", g_strdup((gchar*)value));
+                xmlFree(value);
+            }
+            /* library */
+            if(!xmlStrcmp(node->name, (const xmlChar*)"library")){
+                value = xmlNodeGetContent(node);
+                g_hash_table_insert(object, "library", g_strdup((gchar*)value));
+                xmlFree(value);
+            }
+        }
+        node = node->next;
     }
 }
 /*******************************************************************************/
+gchar*
+get_source_forecast_url(GtkListStore *data, const gchar *source_name){
+    GtkTreeIter iter;
+    GHashTable  *source = NULL;
+    gpointer    value = NULL;
+    gboolean    valid = FALSE;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    if(!data && !source_name)
+        return NULL;
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(data), &iter);
+    while(valid){
+        gtk_tree_model_get(GTK_TREE_MODEL(data), &iter, 1, &source, -1);
+        value = g_hash_table_lookup(source, "name");
+        if(value && !strcmp(source_name, (gchar*)value) &&
+                source_forecast_url_valid(source))
+            return g_hash_table_lookup(source, "forecast_url");
+        valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(data), &iter);
+    }
+    return NULL;
+}
+/*******************************************************************************/
+gchar*
+get_source_detail_url(GtkListStore *data, const gchar *source_name){
+    GtkTreeIter iter;
+    GHashTable  *source = NULL;
+    gpointer    value = NULL;
+    gboolean    valid = FALSE;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    if(!data && !source_name)
+        return NULL;
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(data), &iter);
+    while(valid){
+        gtk_tree_model_get(GTK_TREE_MODEL(data), &iter, 1, &source, -1);
+        value = g_hash_table_lookup(source, "name");
+        if(value && !strcmp(source_name, (gchar*)value) &&
+                source_detail_url_valid(source))
+            return g_hash_table_lookup(source, "detail_url");
+        valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(data), &iter);
+    }
+    return NULL;
+}
+/*******************************************************************************/
+gchar*
+get_source_logo(GtkListStore *data, const gchar *source_name){
+    GtkTreeIter iter;
+    GHashTable  *source = NULL;
+    gpointer    value = NULL;
+    gboolean    valid = FALSE;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    if(!data && !source_name)
+        return NULL;
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(data), &iter);
+    while(valid){
+        gtk_tree_model_get(GTK_TREE_MODEL(data), &iter, 1, &source, -1);
+        value = g_hash_table_lookup(source, "name");
+        if(source_name && value && !strcmp(source_name, (gchar*)value) &&
+                source_logo_file_valid(source))
+            return g_hash_table_lookup(source, "logo");
+        valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(data), &iter);
+    }
+    return NULL;
+}
+/*******************************************************************************/
